@@ -86,7 +86,7 @@
 #define PRISON_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef PRISON_NO_DEPRECATED
-#  define PRISON_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54f00
+#  define PRISON_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55200
 #endif
 #ifdef PRISON_NO_DEPRECATED_WARNINGS
 #  define PRISON_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef PRISON_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define PRISON_DEPRECATED_WARNINGS_SINCE PRISON_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define PRISON_DEPRECATED_WARNINGS_SINCE 0x54f00
+#    define PRISON_DEPRECATED_WARNINGS_SINCE 0x55200
 #  endif
 #endif
 
@@ -124,5 +124,12 @@
 #define PRISON_DEPRECATED_VERSION_5(minor, text)      PRISON_DEPRECATED_VERSION_5_##minor(text)
 #define PRISON_DEPRECATED_VERSION(major, minor, text) PRISON_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define PRISON_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) PRISON_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
+#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
+#  define PRISON_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) PRISON_DEPRECATED_VERSION(major, minor, text)
+#  define PRISON_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) PRISON_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#else
+#  define PRISON_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
+#  define PRISON_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#endif
 
 #endif /* PRISON_EXPORT_H */
